==> haskell-hstringtemplate-0.8.8-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hstringtemplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HStringTemplate
version:              0.8.8
visibility:           public
id:                   HStringTemplate-0.8.8-43pBpTJhHwtBchCwRNlTJd
key:                  HStringTemplate-0.8.8-43pBpTJhHwtBchCwRNlTJd
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             StringTemplate implementation in Haskell.
description:          A port of the Java library by Terrence Parr.
category:             Text
abi:                  cfdbad7b195abd6b592b7dd637f54e01
exposed:              True
exposed-modules:
    Text.StringTemplate Text.StringTemplate.Base
    Text.StringTemplate.Classes Text.StringTemplate.GenericStandard
    Text.StringTemplate.QQ

hidden-modules:
    Text.StringTemplate.Instances Text.StringTemplate.Group
    Text.StringTemplate.Renderf

import-dirs:          /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hstringtemplate
hs-libraries:         HSHStringTemplate-0.8.8-43pBpTJhHwtBchCwRNlTJd
depends:
    array-0.5.4.0 base-4.17.2.1
    blaze-builder-0.4.3-8rH1AueEqNg5izSnHga4uZ bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    mtl-2.2.2 old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    pretty-1.1.3.6 syb-0.7.2.4-KZWFCw0jrXo7PqqEr4StTI
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-hstringtemplate/html/HStringTemplate.haddock

haddock-html:         /usr/share/doc/haskell-hstringtemplate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hstringtemplate-0.8.8-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hstringtemplate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HStringTemplate
version:              0.8.8
visibility:           public
id:                   HStringTemplate-0.8.8-Hz2v6oJk3j3CFaxDRw5MCa
key:                  HStringTemplate-0.8.8-Hz2v6oJk3j3CFaxDRw5MCa
license:              BSD-3-Clause
maintainer:           s.clover@gmail.com
author:               Sterling Clover
synopsis:             StringTemplate implementation in Haskell.
description:          A port of the Java library by Terrence Parr.
category:             Text
abi:                  cdc2c11244577844395058b178d82df9
exposed:              True
exposed-modules:
    Text.StringTemplate Text.StringTemplate.Base
    Text.StringTemplate.Classes Text.StringTemplate.GenericStandard
    Text.StringTemplate.QQ

hidden-modules:
    Text.StringTemplate.Instances Text.StringTemplate.Group
    Text.StringTemplate.Renderf

import-dirs:          /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HStringTemplate-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hstringtemplate
hs-libraries:         HSHStringTemplate-0.8.8-Hz2v6oJk3j3CFaxDRw5MCa
depends:
    array-0.5.4.0 base-4.17.2.1
    blaze-builder-0.4.3-Cn74iEPHjBE4gTddOEs4zL bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    mtl-2.2.2 old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh parsec-3.1.16.1
    pretty-1.1.3.6 syb-0.7.2.4-CLsCb1U1DGkGwwvmeMNNEv
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-hstringtemplate/html/HStringTemplate.haddock

haddock-html:         /usr/share/doc/haskell-hstringtemplate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
